<?php

namespace Drupal\simple_favs\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;

/**
 * Provides a block with a heart icon to toggle favourites.
 *
 * @Block(
 *   id = "simple_favs_heart_block",
 *   admin_label = @Translation("Simple Favs Heart Icon"),
 *   context_definitions = {
 *     "node" = @ContextDefinition("entity:node", required = FALSE)
 *   }
 * )
 */
class SimpleFavsHeartBlock extends BlockBase implements ContainerFactoryPluginInterface {

  protected $routeMatch;

  public function __construct(array $configuration, $plugin_id, $plugin_definition, RouteMatchInterface $route_match) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->routeMatch = $route_match;
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_route_match')
    );
  }

  public function build() {
    $node = $this->routeMatch->getParameter('node');
    if (!$node || !$node->id()) {
      return [];
    }

    $id = $node->id();
    return [
      '#markup' => '<div class="simple-favs-heart" data-id="' . $id . '" role="button" tabindex="0" aria-label="Toggle Favourite"><span class="heart-icon">♡</span></div>',
      '#attached' => [
        'library' => ['simple_favs/heart'],
      ],
    ];
  }
}

